@@ -1,6 +1,6 @@
 package Getopt::Flex::Spec;
 BEGIN {
-  $Getopt::Flex::Spec::VERSION = '1.05';
+  $Getopt::Flex::Spec::VERSION = '1.06';
 }
 
 # ABSTRACT: Getopt::Flex's way of handling an option spec
@@ -40,7 +40,19 @@ sub BUILD {
     my $spec = $self->spec();
     
     my $argmap = $self->_argmap();
-    
+
+	my $help = 0;
+	if($self->_config()->auto_help()) {
+		if(defined($spec->{'help|h'}) || defined($spec->{'help'}) || defined($spec->{'h'})) {
+			Carp::croak "auto_help set, but a switch matching 'help|h' already exists, exiting.";
+		}
+
+		$spec->{'help|h'} = {
+			'var' => \$help,
+			'type' => 'Bool',
+		};
+	}
+
     #create each argument in turn
     foreach my $switch_spec (keys %{$spec}) {
         $spec->{$switch_spec}->{'switchspec'} = $switch_spec;
@@ -155,7 +167,7 @@ Getopt::Flex::Spec - Getopt::Flex's way of handling an option spec
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 DESCRIPTION
 
